==> webgui_7.10.23.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Account.pm <==
package WebGUI::i18n::Dutch::Account;
use utf8;
our $I18N = {
  'Error: Cannot instantiate template' => {
    'lastUpdated' => 1229528295,
    'message' => 'Fout: Het gekozen sjabloon %s kan niet worden verwerkte voor klasse %s .'
  },
  'account className' => {
    'lastUpdated' => 1231712190,
    'message' => 'De perl klassenaam van deze functionaliteit.'
  },
  'account identifier' => {
    'lastUpdated' => 1231712351,
    'message' => 'De identificatie van deze functionaliteit zoals in het configuratiebestand. Standaard identificaties zijn profile (profiel), inbox (postvak in), friends (vrienden), contributions (bijdragen), shop (winkel) en user (gebruiker). Deze standaard identificaties moeten niet vertaald worden!'
  },
  'account layout template' => {
    'lastUpdated' => 1231712372,
    'message' => 'Account layout sjabloon'
  },
  'account title' => {
    'lastUpdated' => 1231712418,
    'message' => 'De titel van deze account functionaliteit, zoals in het configuratiebestand. Macros in de titel worden verwerkt.'
  },
  'account url' => {
    'lastUpdated' => 1231712439,
    'message' => 'Het URL waar deze functionaliteit aangezet kan worden.'
  },
  'account_loop' => {
    'lastUpdated' => 1231712467,
    'message' => 'Een functie met informatie over account functionaliteiten.'
  },
  'back_url' => {
    'lastUpdated' => 1231712526,
    'message' => 'Een URL om het Account scherm te verlaten en terug te gaan naar&nbsp; de website.'
  },
  'common account variables' => {
    'lastUpdated' => 1231712539,
    'message' => 'Normale account variabelen'
  },
  'is_[[IDENTIFIER]]' => {
    'lastUpdated' => 1231712614,
    'message' => '[[IDENTIFIER]] wordt vervangen door de identificatie van de functionaliteit, bijvoorbeeld is_profile. Het resultaat zal waar zijn voor de betreffende functionaliteit.'
  },
  'is_active' => {
    'lastUpdated' => 1231712665,
    'message' => 'Deze variabele zal waar zijn als deze functionaliteit bekeken wordt.'
  },
  'is_method_[[METHOD]]' => {
    'lastUpdated' => 1231712723,
    'message' => '[[METHOD]] wordt vervangen door de naam van de standaard methode van deze functionaliteit. De standaard naam voor deze methode is view (bekijken)'
  },
  'root_url' => {
    'lastUpdated' => 1231712745,
    'message' => 'Het URL om terug te gaan naar het hoofdscherm van de Account.'
  },
  'user_full_name' => {
    'lastUpdated' => 1231712759,
    'message' => 'De volledige naam van de gebruiker.'
  },
  'user_member_since' => {
    'lastUpdated' => 1231712817,
    'message' => 'De datum waarop de gebruiker een account heeft aangemaakt op deze site. Gerbuik het Date macro om de datum anders weer te geven.'
  },
  'view_profile_url' => {
    'lastUpdated' => 1231712839,
    'message' => 'Een URL om het profiel van de gebruiker te bekijken.'
  }
}
;

1;

==> webgui_7.10.24.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Account.pm <==
package WebGUI::i18n::Dutch::Account;
use utf8;
our $I18N = {
  'Error: Cannot instantiate template' => {
    'lastUpdated' => '1229528295',
    'message' => 'Fout: Het gekozen sjabloon %s kan niet worden verwerkte voor klasse %s .'
  },
  'Return to Account' => {
    'lastUpdated' => '1316179872',
    'message' => 'Ga terug naar account'
  },
  'account className' => {
    'lastUpdated' => '1231712190',
    'message' => 'De perl klassenaam van deze functionaliteit.'
  },
  'account identifier' => {
    'lastUpdated' => '1231712351',
    'message' => 'De identificatie van deze functionaliteit zoals in het configuratiebestand. Standaard identificaties zijn profile (profiel), inbox (postvak in), friends (vrienden), contributions (bijdragen), shop (winkel) en user (gebruiker). Deze standaard identificaties moeten niet vertaald worden!'
  },
  'account layout template' => {
    'lastUpdated' => '1231712372',
    'message' => 'Account layout sjabloon'
  },
  'account title' => {
    'lastUpdated' => '1231712418',
    'message' => 'De titel van deze account functionaliteit, zoals in het configuratiebestand. Macros in de titel worden verwerkt.'
  },
  'account url' => {
    'lastUpdated' => '1231712439',
    'message' => 'Het URL waar deze functionaliteit aangezet kan worden.'
  },
  'account_loop' => {
    'lastUpdated' => '1231712467',
    'message' => 'Een functie met informatie over account functionaliteiten.'
  },
  'back_url' => {
    'lastUpdated' => '1231712526',
    'message' => 'Een URL om het Account scherm te verlaten en terug te gaan naar&nbsp; de website.'
  },
  'common account variables' => {
    'lastUpdated' => '1231712539',
    'message' => 'Normale account variabelen'
  },
  'is_[[IDENTIFIER]]' => {
    'lastUpdated' => '1231712614',
    'message' => '[[IDENTIFIER]] wordt vervangen door de identificatie van de functionaliteit, bijvoorbeeld is_profile. Het resultaat zal waar zijn voor de betreffende functionaliteit.'
  },
  'is_active' => {
    'lastUpdated' => '1231712665',
    'message' => 'Deze variabele zal waar zijn als deze functionaliteit bekeken wordt.'
  },
  'is_method_[[METHOD]]' => {
    'lastUpdated' => '1231712723',
    'message' => '[[METHOD]] wordt vervangen door de naam van de standaard methode van deze functionaliteit. De standaard naam voor deze methode is view (bekijken)'
  },
  'root_url' => {
    'lastUpdated' => '1231712745',
    'message' => 'Het URL om terug te gaan naar het hoofdscherm van de Account.'
  },
  'user_full_name' => {
    'lastUpdated' => '1231712759',
    'message' => 'De volledige naam van de gebruiker.'
  },
  'user_member_since' => {
    'lastUpdated' => '1231712817',
    'message' => 'De datum waarop de gebruiker een account heeft aangemaakt op deze site. Gerbuik het Date macro om de datum anders weer te geven.'
  },
  'view_profile_url' => {
    'lastUpdated' => '1231712839',
    'message' => 'Een URL om het profiel van de gebruiker te bekijken.'
  }
}
;

1;
